@@ -2,7 +2,9 @@ package Acme::MetaSyntactic::tour_de_france;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
+
+=encoding iso-8859-1
 
 =head1 NAME
 
@@ -150,6 +152,9 @@ Updated with winners since 2006, and
 received its own version number for Acme-MetaSyntactic-Themes version 1.000,
 published on May 7, 2012.
 
+Updated with an C<=encoding> pod command in version 1.001,
+published on May 14,2012
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
